import os
import time
import uuid
from typing import  Optional

import google.generativeai as genai
import orjson
import requests
from google.generativeai.types import (HarmBlockThreshold, HarmCategory)
from loguru import logger

from utils.feishu_data import Material

CACHE_DIR = '/app/cache/'
# CACHE_DIR = '/Users/z/Downloads/'
# PROXY_ADDR = 'http://localhost:1081'
# os.environ['http_proxy'] = PROXY_ADDR
# os.environ['https_proxy'] = PROXY_ADDR


SAMPLE_DATA = {
    "一、基础信息": {
        "关键维度": "",
        "内容选题": "",
        "视频主题": "",
        "视频关键词":""
    },
    "二、主体和场景": {
        "视频主体": "",
        "视频场景": []
    },
    "三、情感与风格": {
        "情感倾向":"",
        "视频风格":""
    },
    "四、视频传播性与画像": {
        "片尾引导": {},
        "传播性判断": "",
        "视频用户画像": {}
    },
    "五、音画细节": {
        "音频细节": {},
        "视频水印": {},
        "视频字幕": {},
        "视频口播": ""
    },
    "六、封面信息": {
        "封面主体": "",
        "人物个数": "",
        "文字数量": "",
        "文字关键字":[],
        "封面主题":""
    },
    "七、人物与场景": {
        "知名人物":"",
        "人物年龄段":"",
        "场景描述": ""
    },
    "八、时效性与分类": {
        "时效性":"",
        "视频一级分类": "",
        "二级分类": ["品类- 、分数-", "品类- 、分数-", "品类- 、分数-"]
    },
    "九、标题理解": {
    }
}

class GoogleAI(object):

    @classmethod
    def download_video(cls, video_link: str) -> Optional[str]:
        file_path = os.path.join(CACHE_DIR, f'{str(uuid.uuid4())}.mp4')
        for _ in range(3):
            try:
                response = requests.get(url=video_link, timeout=60)
                if response.status_code == 200:
                    with open(file_path, 'wb') as f:
                        f.write(response.content)
                    logger.info(f'[内容分析] 视频链接: {video_link}, 存储地址: {file_path}')
                    return file_path
            except Exception:
                time.sleep(1)
                continue
        return

    @classmethod
    def run(cls, api_key, video_url):
        video_path = None
        try:
            genai.configure(api_key=api_key)
            video_path = cls.download_video(video_link=video_url)
            if not video_path:
                logger.error(f'[内容分析] 视频下载失败, 跳过任务')
                os.remove(video_path)
                logger.info(f"[内容分析] 文件已删除: {video_path}")
                return "[异常] 视频下载失败"

            video = genai.upload_file(path=video_path, mime_type='video/mp4')
            while video.state.name == 'PROCESSING':
                time.sleep(1)
                video = genai.get_file(name=video.name)
            if video.state.name != 'ACTIVE':
                genai.delete_file(name=video.name)
                os.remove(video_path)
                return "[异常] 上传视频失败"
            model = genai.GenerativeModel(
                model_name='gemini-1.5-flash',
                generation_config=genai.GenerationConfig(response_mime_type='application/json'),
                safety_settings={
                    HarmCategory.HARM_CATEGORY_SEXUALLY_EXPLICIT: HarmBlockThreshold.BLOCK_NONE,
                },
            )
            mark, prompt = Material.feishu_list()
            response = model.generate_content(
                contents=[
                    video,
                    f'{prompt}\n输出返回格式样例json输出:\n{SAMPLE_DATA}',
                ],
                stream=False,
                request_options={
                    'timeout': 600,
                },
            )
            text = orjson.loads(response.text.strip())
            genai.delete_file(name=video.name)
            os.remove(video_path)
            return text
        except Exception as e:
            logger.error(f"[内容分析] 处理异常,异常信息{e}")
            os.remove(video_path)
            return f"[异常] {e}"


if __name__ == '__main__':
    ai = GoogleAI()
    ai.run("AIzaSyA_dXKbcW8s0fFIoo89rtPRWU34pJry7mU",
                 "http://rescdn.yishihui.com/jq_oss/video/2025012215472528213")

