import json

import requests
class GPT4oMini:

    @classmethod
    def get_ai_mini_early(cls, title):
        url = "http://aigc-api.cybertogether.net//aigc/dev/test/gpt"
        payload = json.dumps({
            "imageList": [],
            "model": "gpt-4o-mini-2024-07-18",
            "prompt": (
                "你是一个专业的标题分析师，请你通过视频标题来判断视频内容是否属于早安祝福内容。"
                "早安祝福视频标题标准如下："
                "1.标题中含有“早上”、“早上好”、“早安”等带有早安祝福的字眼，则符合"
                "2.标题中带有早安祝福含义"
                f"请严格按照示例输出，标题：{title}。"
            ),
            "responseFormat": {
                "type": "json_schema",
                "json_schema": {
                    "strict": True,
                    "name": "share_script_result",
                    "schema": {
                        "type": "object",
                        "properties": {
                            "是否": {
                                "type": "string",
                                "description": "是否"
                            }
                        },
                        "required": ["是否"],
                        "additionalProperties": False
                    }
                }
            }
        })
        headers = {'Content-Type': 'application/json'}
        try:
            response = requests.post(url, headers=headers, data=payload)
            response_data = response.json()

            data = json.loads(response_data.get('data', '{}'))
            new_title = data["是否"]
            return new_title
        except Exception as e:
            return "否"

    @classmethod
    def get_ai_mini_day_early(cls, title):
        url = "http://aigc-api.cybertogether.net//aigc/dev/test/gpt"
        payload = json.dumps({
            "imageList": [],
            "model": "gpt-4o-mini-2024-07-18",
            "prompt": (
                f"""你是一个专业的标题分析师，请通过视频标题来判断标题中的日期是否与当天日期一致。具体规则如下：

            提取标题中的日期：
            
            若标题中包含“x月x日”或“x月x号”格式的日期（例如“3月4日”或“3月4号”或“3月4”），则提取该日期。
            
            若标题中不包含日期格式，则直接输出“符合日期适合推荐”。
            
            判断日期是否为当天：
            
            若提取的日期与北京时间当天日期一致，则输出“符合日期适合推荐”。
            
            若提取的日期与当天日期不一致，则输出“非当日日期不推荐”。
            
            输出格式：
            
            严格按照以下示例输出：
            
            示例1：标题：“早上好,3月4日最新消息” → 若当天是3月4日，输出“符合日期适合推荐”；。
            
            示例2：标题：“早上好” → 输出“符合日期适合推荐”。
            
            示例3：标题：“早上好,10月10日最新消息” → 若当天不是10月10日，则输出“非当日日期不推荐”；。

            
            请严格按照上述规则和示例输出，标题：{title}。"""


            ),
            "responseFormat": {
                "type": "json_schema",
                "json_schema": {
                    "strict": True,
                    "name": "share_script_result",
                    "schema": {
                        "type": "object",
                        "properties": {
                            "是否": {
                                "type": "string",
                                "description": "是否"
                            }
                        },
                        "required": ["是否"],
                        "additionalProperties": False
                    }
                }
            }
        })
        headers = {'Content-Type': 'application/json'}
        try:
            response = requests.post(url, headers=headers, data=payload)
            response_data = response.json()

            data = json.loads(response_data.get('data', '{}'))
            new_title = data["是否"]
            return new_title
        except Exception as e:
            return "非当日日期不推荐"

if __name__ == '__main__':

    title = GPT4oMini.get_ai_mini_day_early("❤️早上好！今天是3月5日！想得起的，都是真情。合得来的，都是缘分。处得好的，都有共识。经常问候的，都是最难忘的人")
    print(title)