import asyncio
import json
import re
import sys
from datetime import datetime

import orjson
from apscheduler.schedulers.asyncio import AsyncIOScheduler
from apscheduler.triggers.cron import CronTrigger
from loguru import logger


sys.path.append('/app')
from utils.gpt4o_mini_help import GPT4oMini
from utils.piaoquan import PQ
from utils.redis import RedisHelper, content_video_data


class ConsumptionSpiderRecommend(object):
    @classmethod
    def judgment_time(cls,title):
        today = datetime.now().strftime("%-m月%-d")
        date_pattern = r"(\d{1,2}月\d{1,2}([日号]|$))|(\d{4}年\d{1,2}月\d{1,2}日)|(\d{1,2}/\d{1,2})"
        if re.search(date_pattern, title):
            if today in title:
                return True
            else:
                return False
        else:
            return True


    @classmethod
    async def run(cls):
        logger.info(f"[处理] 开始获取redis数据")

        task = RedisHelper().get_client().rpop(name = 'task:pq_hour_early')
        if not task:
            logger.info('[处理] 无待处理的数据')
            return
        task = orjson.loads(task)
        logger.info(f"[处理] 获取redis数据{task}")
        video_title = task['video_title']
        logger.info(f"[处理] 开始分析标题是否符合早上发送，标题:{video_title}")
        title_type = GPT4oMini.get_ai_mini_early(video_title)
        content_video_data(json.dumps({
            "video_id": task['video_id'],
            "video_title": task['video_title'],
            "status": title_type,
            "time": str(datetime.now().strftime("%-m月%-d"))
        }), "task:spider_early_data")
        title_status = cls.judgment_time(video_title)
        if title_type == "否":
            PQ.video_tag(task['video_id'], "lev-供给,rol-机器,#str-早安内容固定时段上推荐base_63")
            logger.info('[处理] 不属于早安祝福内容')
            return
        if title_status:
            logger.info('[处理] 开始上推荐处理')
            code = PQ.pq_recommended(task['video_id'])
            if code:
                logger.info('[处理] 上推荐处理成功')
                PQ.video_tag(task['video_id'], "lev-供给,rol-机器,#str-早安内容固定时段上推荐实验_62")
                logger.info('[处理] 视频打固定标签成功')
            return
        else:
            PQ.video_tag(task['video_id'], "lev-供给,rol-机器,#str-早安内容固定时段上推荐base_63")
            logger.info('[处理] 非当日日期不推荐')
            return



async def run():
    scheduler = AsyncIOScheduler()
    try:
        logger.info(f"[处理] 开始启动")
        scheduler.add_job(
            ConsumptionSpiderRecommend.run,
            trigger=CronTrigger(hour='2-6', minute='*')  # 2:00-6:59 每分钟执行一次
        )
        scheduler.start()
        await asyncio.Event().wait()
    except KeyboardInterrupt:
        pass
    except Exception as e:
        logger.error(f"[处理] 启动异常，异常信息:{e}")
        pass
    finally:
        scheduler.shutdown()


if __name__ == '__main__':
    # asyncio.run(ConsumptionSpiderRecommend.run())
    # loop = asyncio.get_event_loop()
    # loop.run_until_complete(run())
    title = ConsumptionSpiderRecommend.judgment_time("🔴早上好❗2月13号的第一声问候，送给亲爱的你")
    print(title)