import datetime
import sys
import time

import schedule
from loguru import logger
sys.path.append('/app')

from utils.odps_data import OdpsDataCount
from utils.redis import RedisHelper


def bot_video_ai_top():
    """当日头部"""
    try:
        dt = datetime.datetime.now().strftime('%Y%m%d')
        logger.info(f"[R] 当日头部开始获取任务")
        redis_task = 'task:video_ai_pq'
        table_name = 'content_ai_tag_return_top_merge'
        data = OdpsDataCount.main(table_name, dt)
        if not data:
            return
        RedisHelper().get_client().rpush(redis_task, *data)
        logger.info(f"[R] 当日头部写入Redis 成功 共写入 {len(data)} 条")
    except Exception as e:
        logger.error(f"[R] 当日头部写入Redis写入失败，失败信息{e}")


def bot_video_ai_pq():
    """历史数据"""
    try:
        dt = datetime.datetime.now().strftime('%Y%m%d')
        logger.info(f"[R] 历史数据开始获取任务")
        redis_task = 'task:video_ai_pq'
        table_name = 'history_top2000_add_aitags'
        data = OdpsDataCount.main(table_name, dt)
        if not data:
            return
        RedisHelper().get_client().rpush(redis_task, *data)
        logger.info(f"[R] 历史数据写入Redis 成功 共写入 {len(data)} 条")
    except Exception as e:
        logger.error(f"[R] 历史数据写入Redis写入失败，失败信息{e}")


def bot_video_ai_recommend():
    """新推荐"""
    try:
        dt = (datetime.datetime.now() - datetime.timedelta(hours=1)).strftime('%Y%m%d%H') # 获取前一小时
        logger.info(f"[R] 新推荐开始获取任务")
        redis_task = 'task:video_ai_pq'
        table_name = 'content_ai_tag_recommend'
        data = OdpsDataCount.main(table_name, dt)
        if not data:
            return
        RedisHelper().get_client().rpush(redis_task, *data)
        logger.info(f"[R] 新推荐写入Redis 成功 共写入 {len(data)} 条")
    except Exception as e:
        logger.error(f"[R] 新推荐写入Redis写入失败，失败信息{e}")

def schedule_tasks():
    schedule.every().hour.at(":26").do(bot_video_ai_recommend)
    schedule.every().day.at("01:25").do(bot_video_ai_pq)
    schedule.every().day.at("02:25").do(bot_video_ai_top)


if __name__ == "__main__":
    schedule_tasks()  # 调用任务调度函数
    while True:
        schedule.run_pending()
        time.sleep(1)  # 每秒钟检查一次

    # bot_video_ai_recommend()
